## ----include = FALSE----------------------------------------------------------
knitr::opts_chunk$set(
  collapse = TRUE,
  comment = "#>"
)

## ----setup, include = FALSE---------------------------------------------------
library(broadSeq)

## ----eval=FALSE---------------------------------------------------------------
#  library(broadSeq)

## ----warning=FALSE,eval=TRUE--------------------------------------------------
se <- readRDS(system.file("extdata","rat_vole_mouseSE_salmon.rds", package = "broadSeq"))

# To reduce the run time, subset of the data used here
se <- se[,colData(se)$species == "Mouse"]

## ----warning=FALSE,eval=FALSE,echo=FALSE--------------------------------------
#  count_matrix <- as.matrix(read.table(file = system.file("extdata",
#                                                "tooth_RNASeq_counts.txt",
#                                                package = "DELocal")))
#  colData <- data.frame(condition=gsub("\\..*",x=colnames(count_matrix),replacement = ""))
#  
#  gene_location <- read.table(file = system.file("extdata",
#                                                "gene_location.txt",
#                                                package = "DELocal"))
#  
#  se <- SummarizedExperiment::SummarizedExperiment(assays=list(counts=count_matrix),
#                                                        rowData = gene_location,
#                                                        colData=colData)
#  # contrast= c("condition","ME13","ME14")

## ----warning=FALSE------------------------------------------------------------
head(rownames(se))

## ----warning=FALSE,eval=FALSE-------------------------------------------------
#  require(biomaRt)
#  
#  ensembl_ms_mart <- useMart(biomart="ENSEMBL_MART_ENSEMBL",
#                             dataset="mmusculus_gene_ensembl", host="www.ensembl.org")
#  gene_attributes<- c("ensembl_gene_id", "mgi_symbol",
#                      "start_position", "chromosome_name","gene_biotype")
#  gene_location_sample <- getBM(attributes=gene_attributes, filters = "ensembl_gene_id",
#                                values = rownames(se),uniqueRows = TRUE,
#                                mart=ensembl_ms_mart,verbose = FALSE,useCache = TRUE)
#  
#  # remove rows with duplicate ensembl_gene_id
#  gene_location_sample <- gene_location_sample[!duplicated(gene_location_sample$ensembl_gene_id),]
#  # some ensembl_gene_id may not be found in biomart
#  # remove those ensembl_gene_id s
#  se <- se[gene_location_sample$ensembl_gene_id,]
#  
#  rownames(gene_location_sample) <- gene_location_sample$ensembl_gene_id
#  rowData(se) <- gene_location_sample[rownames(se),]

## ----warning=FALSE,eval=FALSE-------------------------------------------------
#  head(rowData(se))

## ----warning=FALSE,eval=TRUE--------------------------------------------------
head(colData(se))
table(colData(se)$stage)

## ----warning=FALSE,fig.width=6,fig.height=6,message=FALSE---------------------
result_Noiseq <- 
    use_NOIseq(se = se, 
           colData_id = "stage", control = "Bud", treatment = "Cap",
           rank = TRUE, 
           r = 10) # r is an argument of NOISeq::noiseqbio

head(result_Noiseq)

## ----warning=FALSE,fig.width=8,fig.height=6,message=FALSE---------------------
# boxplot of top four DE genes with their mgi_symbol

# broadSeq::genes_plot function internally converts SummarizedExperiment to use
# ggpubr::ggboxplot 

pg <- broadSeq::genes_plot(se, x = "stage", assayName =  "counts",  
           features = result_Noiseq %>% dplyr::filter(rank <5) %>% rownames(),
           fill="stage", facet.by = "symbol",
           palette="jco", add = "dotplot")+rotate_x_text()

pg_sc <- ggscatter(result_Noiseq, x="Bud_mean", y="Cap_mean",color = "prob")+ 
    scale_x_log10()+scale_y_log10()

pg+pg_sc

## ----warning=FALSE,results="hide", fig.keep = "none"--------------------------
# limma 
?use_limma_trend(se, colData_id, control, treatment, rank = FALSE, ...)
?use_limma_voom(se, colData_id, control, treatment, rank = FALSE, ...)

# edgeR 
?use_edgeR_exact(se, colData_id, control, treatment, rank = FALSE, ...)
?use_edgeR_GLM(se, colData_id, control, treatment, rank = FALSE, ...)

# deseq2
?use_deseq2(se, colData_id, control, treatment, rank = FALSE, ...)

# DELocal
?use_DELocal(se, colData_id, control, treatment, rank = FALSE, ...)

# noiseq
?use_NOIseq(se, colData_id, control, treatment, rank = FALSE, ...) 

# EBSeq 
?use_EBSeq(se, colData_id, control, treatment, rank = FALSE, ...)

# samseq
?use_SAMseq(se, colData_id, control, treatment, rank = FALSE, ...)

## ----warning=FALSE,results="hide", fig.keep = "none"--------------------------
# First define a named list of functions
funs <- list(limma_trend = use_limma_trend, limma_voom = use_limma_voom,
             edgeR_exact = use_edgeR_exact, edgeR_glm = use_edgeR_GLM,
             deseq2 = use_deseq2, 
             DELocal = use_DELocal, noiseq = use_NOIseq, 
             EBSeq = use_EBSeq) 


multi_result <- broadSeq::use_multDE(
    se = se, 
    deFun_list = funs, return.df = TRUE,  
    colData_id = "stage", control = "Bud", treatment = "Cap", 
    rank = TRUE)

## ----warning=FALSE------------------------------------------------------------
head(multi_result)
# nrow(multi_result) == nrow(se)
colnames(multi_result)

## ----warning=FALSE,fig.width=6,fig.height=6,eval=TRUE-------------------------
clusters <- multi_result %>% dplyr::select(ends_with("rank")) %>% t() %>% dist() %>% hclust()
plot(clusters,main =  "distance: Euclidean")

## ----warning=FALSE,fig.width=6,fig.height=6,eval=TRUE-------------------------
multi_result %>% broadSeq::volcanoPlot(
    pValName = "deseq2_padj",
    lFCName = "deseq2_log2FoldChange",
    labelName = "symbol",
    palette = "lancet" ,
    selectedLabel =
        multi_result %>% dplyr::arrange(deseq2_padj) %>% pull(symbol) %>% head()
)

multi_result %>% broadSeq::volcanoPlot(
    pValName = "deseq2_padj",
    lFCName = "deseq2_log2FoldChange",
    labelName = "symbol",
    palette = c("purple","orange","grey"),
    selectedLabel = list(criteria = "(`x` > 5 | `x` < -2) & (`y` > 10)")
) +xlim(-7.5,7.5)

## ----warning=FALSE,fig.width=6,fig.height=6,eval=FALSE,echo=FALSE-------------
#  multi_result %>% dplyr::arrange(deseq2_padj) %>% pull(ensembl_gene_id) %>% head()
#  genes_plot(se, features = c("ENSMUSG00000035095","ENSMUSG00000037217"),
#             x = "condition", y = "counts", add = "dotplot",palette = "npg")
#  genes_plot(se, features = c("ENSMUSG00000035095","ENSMUSG00000037217"),
#             x = "condition", y = "counts", fill="condition", add = "jitter",palette = "npg")

## ----warning=FALSE,fig.width=6,fig.height=6,eval=FALSE,echo=FALSE-------------
#  # distinct_ranks <- which(cutree(clusters, k = 6) >1) %>% names()
#  distinct_ranks <- c("DELocal_rank", "limma_voom_rank","edgeR_glm_rank","EBSeq_rank") #,"bayseq_rank"
#  other_cols <- c("limma_voom_logFC","limma_voom_adj.P.Val","DELocal_adj.P.Val","limma_voom_AveExpr")
#  
#  multi_result$ENSEMBL <- row.names(multi_result)
#  
#  
#  multi_result <- multi_result %>% mutate(DE_method =
#                                            ifelse((limma_voom_adj.P.Val < 0.05 & DELocal_adj.P.Val < 0.05), "Both",
#                                                   ifelse(limma_voom_adj.P.Val < 0.05, "limma",
#                                                          ifelse(DELocal_adj.P.Val < 0.05, "DELocal",
#                                                                 NA))) )
#  multi_result$DE_method <- factor(multi_result$DE_method,levels = c("DELocal","Both","limma",NA))
#  multi_result %>% dplyr::select(c(other_cols,distinct_ranks)) %>%
#    arrange(DELocal_rank) %>% head()
#  
#  only_delocal_gene <- multi_result %>% dplyr::filter(DE_method=="DELocal") %>%
#      arrange(DELocal_rank) %>% pull(ensembl_gene_id)
#  
#  # needs to implement using ggpubr
#  DELocal::plotNeighbourhood(pse = se,pDesign = ~ condition,
#                                   pGene_id = only_delocal_gene[1])$plot +
#    labs(title = names(only_delocal_gene[1]))
#  
#  DELocal::plotNeighbourhood(pse = se,pDesign = ~ condition,
#                                   pGene_id = only_delocal_gene[2])$plot +
#    labs(title = names(only_delocal_gene[2]))
#  
#  DELocal::plotNeighbourhood(pse = se,pDesign = ~ condition,
#                                   pGene_id = only_delocal_gene[3])$plot +
#    labs(title = names(only_delocal_gene[3]))
#  
#  

## ----echo=FALSE,warning=FALSE,message=FALSE,eval=FALSE------------------------
#  multi_result[high_dev_gene,] %>% dplyr::select(c(other_cols,distinct_ranks)) %>%
#    arrange(DELocal_rank) %>%
#    write.csv(file = "multi_result_selected_col.csv",row.names = T)
#  
#  top_delocal_high_dev_gene <- multi_result[high_dev_gene,] %>% dplyr::select(ends_with("rank")) %>%
#    arrange(DELocal_rank) %>% rownames()
#  
#  for (gene in head(top_delocal_high_dev_gene)) {
#   DELocal::plotNeighbourhood(pse = se,pDesign = ~ condition, pGene_id = gene)$plot %>% print()
#  }
#  
#  pdf("high_devolopmental_genePlots.pdf")
#  for (gene in top_delocal_high_dev_gene) {
#    # x <- multi_result[gene,] %>% dplyr::select(c(other_cols,distinct_ranks)) %>% round(digits = 4)
#    # paste(names(x), x, sep = ":", collapse = "\n")
#   DELocal::plotNeighbourhood(pse = se,pDesign = ~ condition, pGene_id = gene)$plot %>% print()
#  }
#  dev.off()

## ----echo=FALSE,warning=FALSE,eval=FALSE--------------------------------------
#  delocal_dev_choice <- rnaSeq_median_xprsn_devGenes %>%
#    dplyr::filter(ENSEMBL %in% rownames(DELocal_result %>% filter(adj.P.Val < 0.05)) &
#                    (rnaSeq_median_E14_Tooth > E14_Tooth_75_percentile |
#                       rnaSeq_median_E13_Tooth > E13_Tooth_75_percentile))
#  
#  DELocal_result[rnaSeq_median_xprsn_devGenes$ENSEMBL,] %>% arrange(rank) %>% head()
#  
#  rnaSeq_median_xprsn %>% filter(ENSEMBL=="ENSMUSG00000024598")
#  gPlot <- DELocal:::plotNeighbourhood(se,pDesign = ~ condition, pGene_id = "ENSMUSG00000024598")
#  
#  rnaSeq_median_xprsn_devGenes %>% ggplot(aes(rnaSeq_median_E13_Tooth,rnaSeq_median_E14_Tooth,label=SYMBOL)) +
#    geom_point()+
#    geom_hline(yintercept = E14_Tooth_75_percentile,)+ geom_vline(xintercept = E13_Tooth_75_percentile)+
#    ggrepel::geom_text_repel(
#      data = delocal_dev_choice,
#      nudge_y = 2,
#      segment.size  = 0.2,
#      segment.color = "grey50",
#      direction     = "x"
#  )

## ----echo=FALSE,message=FALSE,warning=FALSE,error=FALSE-----------------------
sessionInfo()

